@@ -2,7 +2,7 @@ var searchData=
 [
   ['fileselected_0',['fileSelected',['../classQtUtilities_1_1RecentMenuManager.html#a59929cfeb7a6232286cd452fe39d465b',1,'QtUtilities::RecentMenuManager']]],
   ['filteracceptsrow_1',['filterAcceptsRow',['../classQtUtilities_1_1OptionCategoryFilterModel.html#afc553a23a7ccd7f3e10aecdf35d03292',1,'QtUtilities::OptionCategoryFilterModel']]],
-  ['flags_2',['flags',['../classQtUtilities_1_1ChecklistModel.html#af76d15ffce96730268a1c84a0563ee0a',1,'QtUtilities::ChecklistModel::flags()'],['../classQtUtilities_1_1PaletteModel.html#a141483fca3196726bb76cc71c99af15c',1,'QtUtilities::PaletteModel::flags()']]],
+  ['flags_2',['flags',['../classQtUtilities_1_1UpdateNotifier.html#ac45e886ffbc45bb31fec952b04c0a30c',1,'QtUtilities::UpdateNotifier::flags()'],['../classQtUtilities_1_1ChecklistModel.html#af76d15ffce96730268a1c84a0563ee0a',1,'QtUtilities::ChecklistModel::flags()'],['../classQtUtilities_1_1PaletteModel.html#a141483fca3196726bb76cc71c99af15c',1,'QtUtilities::PaletteModel::flags()']]],
   ['fromaction_3',['fromAction',['../classQtUtilities_1_1IconButton.html#ab1c8ef59a24a42f3294a1eb711cf0f33',1,'QtUtilities::IconButton']]],
   ['fromdbusargument_4',['fromDBusArgument',['../structQtUtilities_1_1NotificationImage.html#abc012bd082cb3c0002edcc7dcef8b3f8',1,'QtUtilities::NotificationImage']]],
   ['fromnativefilename_5',['fromNativeFileName',['../namespaceQtUtilities.html#a750bda2d3a8b78feacebe9d6098edb9a',1,'QtUtilities::fromNativeFileName(const char *nativeFileName, int size=-1)'],['../namespaceQtUtilities.html#a763b213a46a9c3cfd411f9a25e2c7ba3',1,'QtUtilities::fromNativeFileName(const std::string &amp;nativeFileName)']]]
